const fileInput = document.getElementById("fileInput");
const fileNameDisplay = document.getElementById("fileName");
const imagePreview = document.getElementById("imagePreview");
const formatSelect = document.getElementById("formatSelect");
const qualitySlider = document.getElementById("qualitySlider");
const qualityValue = document.getElementById("qualityValue");
const convertBtn = document.getElementById("convertBtn");

// Update quality value display
qualitySlider.addEventListener("input", () => {
    qualityValue.textContent = `${Math.round(
        qualitySlider.value * 100
    )}%`;
});

// Handle file input
fileInput.addEventListener("change", (e) => {
    const file = e.target.files[0];
    document.querySelector('.preview-section').style.display = '';
    document.querySelector('.settings').style.display = '';
    fileNameDisplay.style.display = '';
    if (file) {
        fileNameDisplay.textContent = file.name;
        const reader = new FileReader();
        reader.onload = (event) => {
            imagePreview.src = event.target.result;
            imagePreview.style.display = "block";
        };
        reader.readAsDataURL(file);
    }
});

// Convert and download image
convertBtn.addEventListener("click", async () => {
    const file = fileInput.files[0];
    if (!file) {
        alert("Please upload an AVIF file first.");
        return;
    }

    const options = {
        maxSizeMB: 1,
        maxWidthOrHeight: 1024,
        useWebWorker: true,
        fileType: formatSelect.value,
        initialQuality: qualitySlider.value,
    };

    try {
        const compressedFile = await imageCompression(
            file,
            options
        );
        const downloadLink = document.createElement("a");
        downloadLink.href = URL.createObjectURL(compressedFile);
        downloadLink.download = `converted.${formatSelect.value}`;
        downloadLink.click();
    } catch (error) {
        console.error("Error converting file:", error);
        alert("An error occurred during conversion.");
    }
});